==> devops-client-java-1.0.6-sources.jar: io/alauda/devops/java/client/models/V1alpha1PipelineTaskTemplateSpecFluent.java <==
package io.alauda.devops.java.client.models;

import java.lang.StringBuilder;
import com.google.gson.annotations.SerializedName;
import io.alauda.devops.java.client.fluent.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.alauda.devops.java.client.fluent.Predicate;
import java.lang.Deprecated;
import java.util.List;
import java.lang.Boolean;
import io.alauda.devops.java.client.fluent.Fluent;
import java.lang.StringBuffer;
import java.util.Collection;

public interface V1alpha1PipelineTaskTemplateSpecFluent<A extends V1alpha1PipelineTaskTemplateSpecFluent<A>> extends Fluent<A>{


    
/**
 * This method has been deprecated, please use method buildAgent instead.
 * @return The buildable object.
 */
@Deprecated public V1alpha1JenkinsAgent getAgent();
    public V1alpha1JenkinsAgent buildAgent();
    public A withAgent(V1alpha1JenkinsAgent agent);
    public Boolean hasAgent();
    public V1alpha1PipelineTaskTemplateSpecFluent.AgentNested<A> withNewAgent();
    public V1alpha1PipelineTaskTemplateSpecFluent.AgentNested<A> withNewAgentLike(V1alpha1JenkinsAgent item);
    public V1alpha1PipelineTaskTemplateSpecFluent.AgentNested<A> editAgent();
    public V1alpha1PipelineTaskTemplateSpecFluent.AgentNested<A> editOrNewAgent();
    public V1alpha1PipelineTaskTemplateSpecFluent.AgentNested<A> editOrNewAgentLike(V1alpha1JenkinsAgent item);
    public A addToArguments(int index,V1alpha1PipelineTaskArgument item);
    public A setToArguments(int index,V1alpha1PipelineTaskArgument item);
    public A addToArguments(V1alpha1PipelineTaskArgument... items);
    public A addAllToArguments(Collection<V1alpha1PipelineTaskArgument> items);
    public A removeFromArguments(V1alpha1PipelineTaskArgument... items);
    public A removeAllFromArguments(Collection<V1alpha1PipelineTaskArgument> items);
    
/**
 * This method has been deprecated, please use method buildArguments instead.
 * @return The buildable object.
 */
@Deprecated public List<V1alpha1PipelineTaskArgument> getArguments();
    public List<V1alpha1PipelineTaskArgument> buildArguments();
    public V1alpha1PipelineTaskArgument buildArgument(int index);
    public V1alpha1PipelineTaskArgument buildFirstArgument();
    public V1alpha1PipelineTaskArgument buildLastArgument();
    public V1alpha1PipelineTaskArgument buildMatchingArgument(io.alauda.devops.java.client.fluent.Predicate<V1alpha1PipelineTaskArgumentBuilder> predicate);
    public Boolean hasMatchingArgument(io.alauda.devops.java.client.fluent.Predicate<V1alpha1PipelineTaskArgumentBuilder> predicate);
    public A withArguments(List<V1alpha1PipelineTaskArgument> arguments);
    public A withArguments(V1alpha1PipelineTaskArgument... arguments);
    public Boolean hasArguments();
    public V1alpha1PipelineTaskTemplateSpecFluent.ArgumentsNested<A> addNewArgument();
    public V1alpha1PipelineTaskTemplateSpecFluent.ArgumentsNested<A> addNewArgumentLike(V1alpha1PipelineTaskArgument item);
    public V1alpha1PipelineTaskTemplateSpecFluent.ArgumentsNested<A> setNewArgumentLike(int index,V1alpha1PipelineTaskArgument item);
    public V1alpha1PipelineTaskTemplateSpecFluent.ArgumentsNested<A> editArgument(int index);
    public V1alpha1PipelineTaskTemplateSpecFluent.ArgumentsNested<A> editFirstArgument();
    public V1alpha1PipelineTaskTemplateSpecFluent.ArgumentsNested<A> editLastArgument();
    public V1alpha1PipelineTaskTemplateSpecFluent.ArgumentsNested<A> editMatchingArgument(io.alauda.devops.java.client.fluent.Predicate<V1alpha1PipelineTaskArgumentBuilder> predicate);
    public String getBody();
    public A withBody(String body);
    public Boolean hasBody();
    public A withNewBody(String arg1);
    public A withNewBody(StringBuilder arg1);
    public A withNewBody(StringBuffer arg1);
    
/**
 * This method has been deprecated, please use method buildDependencies instead.
 * @return The buildable object.
 */
@Deprecated public V1alpha1PipelineDependency getDependencies();
    public V1alpha1PipelineDependency buildDependencies();
    public A withDependencies(V1alpha1PipelineDependency dependencies);
    public Boolean hasDependencies();
    public V1alpha1PipelineTaskTemplateSpecFluent.DependenciesNested<A> withNewDependencies();
    public V1alpha1PipelineTaskTemplateSpecFluent.DependenciesNested<A> withNewDependenciesLike(V1alpha1PipelineDependency item);
    public V1alpha1PipelineTaskTemplateSpecFluent.DependenciesNested<A> editDependencies();
    public V1alpha1PipelineTaskTemplateSpecFluent.DependenciesNested<A> editOrNewDependencies();
    public V1alpha1PipelineTaskTemplateSpecFluent.DependenciesNested<A> editOrNewDependenciesLike(V1alpha1PipelineDependency item);
    public String getEngine();
    public A withEngine(String engine);
    public Boolean hasEngine();
    public A withNewEngine(String arg1);
    public A withNewEngine(StringBuilder arg1);
    public A withNewEngine(StringBuffer arg1);
    public A addToExports(int index,V1alpha1GlobalParameter item);
    public A setToExports(int index,V1alpha1GlobalParameter item);
    public A addToExports(V1alpha1GlobalParameter... items);
    public A addAllToExports(Collection<V1alpha1GlobalParameter> items);
    public A removeFromExports(V1alpha1GlobalParameter... items);
    public A removeAllFromExports(Collection<V1alpha1GlobalParameter> items);
    
/**
 * This method has been deprecated, please use method buildExports instead.
 * @return The buildable object.
 */
@Deprecated public List<V1alpha1GlobalParameter> getExports();
    public List<V1alpha1GlobalParameter> buildExports();
    public V1alpha1GlobalParameter buildExport(int index);
    public V1alpha1GlobalParameter buildFirstExport();
    public V1alpha1GlobalParameter buildLastExport();
    public V1alpha1GlobalParameter buildMatchingExport(io.alauda.devops.java.client.fluent.Predicate<V1alpha1GlobalParameterBuilder> predicate);
    public Boolean hasMatchingExport(io.alauda.devops.java.client.fluent.Predicate<V1alpha1GlobalParameterBuilder> predicate);
    public A withExports(List<V1alpha1GlobalParameter> exports);
    public A withExports(V1alpha1GlobalParameter... exports);
    public Boolean hasExports();
    public V1alpha1PipelineTaskTemplateSpecFluent.ExportsNested<A> addNewExport();
    public V1alpha1PipelineTaskTemplateSpecFluent.ExportsNested<A> addNewExportLike(V1alpha1GlobalParameter item);
    public V1alpha1PipelineTaskTemplateSpecFluent.ExportsNested<A> setNewExportLike(int index,V1alpha1GlobalParameter item);
    public V1alpha1PipelineTaskTemplateSpecFluent.ExportsNested<A> editExport(int index);
    public V1alpha1PipelineTaskTemplateSpecFluent.ExportsNested<A> editFirstExport();
    public V1alpha1PipelineTaskTemplateSpecFluent.ExportsNested<A> editLastExport();
    public V1alpha1PipelineTaskTemplateSpecFluent.ExportsNested<A> editMatchingExport(io.alauda.devops.java.client.fluent.Predicate<V1alpha1GlobalParameterBuilder> predicate);
    public A addToParameters(int index,V1alpha1PipelineParameter item);
    public A setToParameters(int index,V1alpha1PipelineParameter item);
    public A addToParameters(V1alpha1PipelineParameter... items);
    public A addAllToParameters(Collection<V1alpha1PipelineParameter> items);
    public A removeFromParameters(V1alpha1PipelineParameter... items);
    public A removeAllFromParameters(Collection<V1alpha1PipelineParameter> items);
    
/**
 * This method has been deprecated, please use method buildParameters instead.
 * @return The buildable object.
 */
@Deprecated public List<V1alpha1PipelineParameter> getParameters();
    public List<V1alpha1PipelineParameter> buildParameters();
    public V1alpha1PipelineParameter buildParameter(int index);
    public V1alpha1PipelineParameter buildFirstParameter();
    public V1alpha1PipelineParameter buildLastParameter();
    public V1alpha1PipelineParameter buildMatchingParameter(io.alauda.devops.java.client.fluent.Predicate<V1alpha1PipelineParameterBuilder> predicate);
    public Boolean hasMatchingParameter(io.alauda.devops.java.client.fluent.Predicate<V1alpha1PipelineParameterBuilder> predicate);
    public A withParameters(List<V1alpha1PipelineParameter> parameters);
    public A withParameters(V1alpha1PipelineParameter... parameters);
    public Boolean hasParameters();
    public V1alpha1PipelineTaskTemplateSpecFluent.ParametersNested<A> addNewParameter();
    public V1alpha1PipelineTaskTemplateSpecFluent.ParametersNested<A> addNewParameterLike(V1alpha1PipelineParameter item);
    public V1alpha1PipelineTaskTemplateSpecFluent.ParametersNested<A> setNewParameterLike(int index,V1alpha1PipelineParameter item);
    public V1alpha1PipelineTaskTemplateSpecFluent.ParametersNested<A> editParameter(int index);
    public V1alpha1PipelineTaskTemplateSpecFluent.ParametersNested<A> editFirstParameter();
    public V1alpha1PipelineTaskTemplateSpecFluent.ParametersNested<A> editLastParameter();
    public V1alpha1PipelineTaskTemplateSpecFluent.ParametersNested<A> editMatchingParameter(io.alauda.devops.java.client.fluent.Predicate<V1alpha1PipelineParameterBuilder> predicate);

    public interface AgentNested<N> extends io.alauda.devops.java.client.fluent.Nested<N>,V1alpha1JenkinsAgentFluent<V1alpha1PipelineTaskTemplateSpecFluent.AgentNested<N>>{

        
    public N and();    public N endAgent();
}
    public interface ArgumentsNested<N> extends io.alauda.devops.java.client.fluent.Nested<N>,V1alpha1PipelineTaskArgumentFluent<V1alpha1PipelineTaskTemplateSpecFluent.ArgumentsNested<N>>{

        
    public N and();    public N endArgument();
}
    public interface DependenciesNested<N> extends io.alauda.devops.java.client.fluent.Nested<N>,V1alpha1PipelineDependencyFluent<V1alpha1PipelineTaskTemplateSpecFluent.DependenciesNested<N>>{

        
    public N and();    public N endDependencies();
}
    public interface ExportsNested<N> extends io.alauda.devops.java.client.fluent.Nested<N>,V1alpha1GlobalParameterFluent<V1alpha1PipelineTaskTemplateSpecFluent.ExportsNested<N>>{

        
    public N and();    public N endExport();
}
    public interface ParametersNested<N> extends io.alauda.devops.java.client.fluent.Nested<N>,V1alpha1PipelineParameterFluent<V1alpha1PipelineTaskTemplateSpecFluent.ParametersNested<N>>{

        
    public N and();    public N endParameter();
}


}

==> devops-client-java-1.0.7.1-sources.jar: io/alauda/devops/java/client/models/V1alpha1PipelineTaskTemplateSpecFluent.java <==
package io.alauda.devops.java.client.models;

import java.lang.StringBuilder;
import com.google.gson.annotations.SerializedName;
import io.alauda.devops.java.client.fluent.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.alauda.devops.java.client.fluent.Predicate;
import java.lang.Deprecated;
import java.util.List;
import java.lang.Boolean;
import io.alauda.devops.java.client.fluent.Fluent;
import java.lang.StringBuffer;
import java.util.Collection;

public interface V1alpha1PipelineTaskTemplateSpecFluent<A extends V1alpha1PipelineTaskTemplateSpecFluent<A>> extends Fluent<A>{


    
/**
 * This method has been deprecated, please use method buildAgent instead.
 * @return The buildable object.
 */
@Deprecated public V1alpha1JenkinsAgent getAgent();
    public V1alpha1JenkinsAgent buildAgent();
    public A withAgent(V1alpha1JenkinsAgent agent);
    public Boolean hasAgent();
    public V1alpha1PipelineTaskTemplateSpecFluent.AgentNested<A> withNewAgent();
    public V1alpha1PipelineTaskTemplateSpecFluent.AgentNested<A> withNewAgentLike(V1alpha1JenkinsAgent item);
    public V1alpha1PipelineTaskTemplateSpecFluent.AgentNested<A> editAgent();
    public V1alpha1PipelineTaskTemplateSpecFluent.AgentNested<A> editOrNewAgent();
    public V1alpha1PipelineTaskTemplateSpecFluent.AgentNested<A> editOrNewAgentLike(V1alpha1JenkinsAgent item);
    public A addToArguments(int index,V1alpha1PipelineTaskArgument item);
    public A setToArguments(int index,V1alpha1PipelineTaskArgument item);
    public A addToArguments(V1alpha1PipelineTaskArgument... items);
    public A addAllToArguments(Collection<V1alpha1PipelineTaskArgument> items);
    public A removeFromArguments(V1alpha1PipelineTaskArgument... items);
    public A removeAllFromArguments(Collection<V1alpha1PipelineTaskArgument> items);
    
/**
 * This method has been deprecated, please use method buildArguments instead.
 * @return The buildable object.
 */
@Deprecated public List<V1alpha1PipelineTaskArgument> getArguments();
    public List<V1alpha1PipelineTaskArgument> buildArguments();
    public V1alpha1PipelineTaskArgument buildArgument(int index);
    public V1alpha1PipelineTaskArgument buildFirstArgument();
    public V1alpha1PipelineTaskArgument buildLastArgument();
    public V1alpha1PipelineTaskArgument buildMatchingArgument(io.alauda.devops.java.client.fluent.Predicate<V1alpha1PipelineTaskArgumentBuilder> predicate);
    public Boolean hasMatchingArgument(io.alauda.devops.java.client.fluent.Predicate<V1alpha1PipelineTaskArgumentBuilder> predicate);
    public A withArguments(List<V1alpha1PipelineTaskArgument> arguments);
    public A withArguments(V1alpha1PipelineTaskArgument... arguments);
    public Boolean hasArguments();
    public V1alpha1PipelineTaskTemplateSpecFluent.ArgumentsNested<A> addNewArgument();
    public V1alpha1PipelineTaskTemplateSpecFluent.ArgumentsNested<A> addNewArgumentLike(V1alpha1PipelineTaskArgument item);
    public V1alpha1PipelineTaskTemplateSpecFluent.ArgumentsNested<A> setNewArgumentLike(int index,V1alpha1PipelineTaskArgument item);
    public V1alpha1PipelineTaskTemplateSpecFluent.ArgumentsNested<A> editArgument(int index);
    public V1alpha1PipelineTaskTemplateSpecFluent.ArgumentsNested<A> editFirstArgument();
    public V1alpha1PipelineTaskTemplateSpecFluent.ArgumentsNested<A> editLastArgument();
    public V1alpha1PipelineTaskTemplateSpecFluent.ArgumentsNested<A> editMatchingArgument(io.alauda.devops.java.client.fluent.Predicate<V1alpha1PipelineTaskArgumentBuilder> predicate);
    public String getBody();
    public A withBody(String body);
    public Boolean hasBody();
    public A withNewBody(String arg1);
    public A withNewBody(StringBuilder arg1);
    public A withNewBody(StringBuffer arg1);
    
/**
 * This method has been deprecated, please use method buildDependencies instead.
 * @return The buildable object.
 */
@Deprecated public V1alpha1PipelineDependency getDependencies();
    public V1alpha1PipelineDependency buildDependencies();
    public A withDependencies(V1alpha1PipelineDependency dependencies);
    public Boolean hasDependencies();
    public V1alpha1PipelineTaskTemplateSpecFluent.DependenciesNested<A> withNewDependencies();
    public V1alpha1PipelineTaskTemplateSpecFluent.DependenciesNested<A> withNewDependenciesLike(V1alpha1PipelineDependency item);
    public V1alpha1PipelineTaskTemplateSpecFluent.DependenciesNested<A> editDependencies();
    public V1alpha1PipelineTaskTemplateSpecFluent.DependenciesNested<A> editOrNewDependencies();
    public V1alpha1PipelineTaskTemplateSpecFluent.DependenciesNested<A> editOrNewDependenciesLike(V1alpha1PipelineDependency item);
    public String getEngine();
    public A withEngine(String engine);
    public Boolean hasEngine();
    public A withNewEngine(String arg1);
    public A withNewEngine(StringBuilder arg1);
    public A withNewEngine(StringBuffer arg1);
    public A addToExports(int index,V1alpha1GlobalParameter item);
    public A setToExports(int index,V1alpha1GlobalParameter item);
    public A addToExports(V1alpha1GlobalParameter... items);
    public A addAllToExports(Collection<V1alpha1GlobalParameter> items);
    public A removeFromExports(V1alpha1GlobalParameter... items);
    public A removeAllFromExports(Collection<V1alpha1GlobalParameter> items);
    
/**
 * This method has been deprecated, please use method buildExports instead.
 * @return The buildable object.
 */
@Deprecated public List<V1alpha1GlobalParameter> getExports();
    public List<V1alpha1GlobalParameter> buildExports();
    public V1alpha1GlobalParameter buildExport(int index);
    public V1alpha1GlobalParameter buildFirstExport();
    public V1alpha1GlobalParameter buildLastExport();
    public V1alpha1GlobalParameter buildMatchingExport(io.alauda.devops.java.client.fluent.Predicate<V1alpha1GlobalParameterBuilder> predicate);
    public Boolean hasMatchingExport(io.alauda.devops.java.client.fluent.Predicate<V1alpha1GlobalParameterBuilder> predicate);
    public A withExports(List<V1alpha1GlobalParameter> exports);
    public A withExports(V1alpha1GlobalParameter... exports);
    public Boolean hasExports();
    public V1alpha1PipelineTaskTemplateSpecFluent.ExportsNested<A> addNewExport();
    public V1alpha1PipelineTaskTemplateSpecFluent.ExportsNested<A> addNewExportLike(V1alpha1GlobalParameter item);
    public V1alpha1PipelineTaskTemplateSpecFluent.ExportsNested<A> setNewExportLike(int index,V1alpha1GlobalParameter item);
    public V1alpha1PipelineTaskTemplateSpecFluent.ExportsNested<A> editExport(int index);
    public V1alpha1PipelineTaskTemplateSpecFluent.ExportsNested<A> editFirstExport();
    public V1alpha1PipelineTaskTemplateSpecFluent.ExportsNested<A> editLastExport();
    public V1alpha1PipelineTaskTemplateSpecFluent.ExportsNested<A> editMatchingExport(io.alauda.devops.java.client.fluent.Predicate<V1alpha1GlobalParameterBuilder> predicate);
    public A addToParameters(int index,V1alpha1PipelineParameter item);
    public A setToParameters(int index,V1alpha1PipelineParameter item);
    public A addToParameters(V1alpha1PipelineParameter... items);
    public A addAllToParameters(Collection<V1alpha1PipelineParameter> items);
    public A removeFromParameters(V1alpha1PipelineParameter... items);
    public A removeAllFromParameters(Collection<V1alpha1PipelineParameter> items);
    
/**
 * This method has been deprecated, please use method buildParameters instead.
 * @return The buildable object.
 */
@Deprecated public List<V1alpha1PipelineParameter> getParameters();
    public List<V1alpha1PipelineParameter> buildParameters();
    public V1alpha1PipelineParameter buildParameter(int index);
    public V1alpha1PipelineParameter buildFirstParameter();
    public V1alpha1PipelineParameter buildLastParameter();
    public V1alpha1PipelineParameter buildMatchingParameter(io.alauda.devops.java.client.fluent.Predicate<V1alpha1PipelineParameterBuilder> predicate);
    public Boolean hasMatchingParameter(io.alauda.devops.java.client.fluent.Predicate<V1alpha1PipelineParameterBuilder> predicate);
    public A withParameters(List<V1alpha1PipelineParameter> parameters);
    public A withParameters(V1alpha1PipelineParameter... parameters);
    public Boolean hasParameters();
    public V1alpha1PipelineTaskTemplateSpecFluent.ParametersNested<A> addNewParameter();
    public V1alpha1PipelineTaskTemplateSpecFluent.ParametersNested<A> addNewParameterLike(V1alpha1PipelineParameter item);
    public V1alpha1PipelineTaskTemplateSpecFluent.ParametersNested<A> setNewParameterLike(int index,V1alpha1PipelineParameter item);
    public V1alpha1PipelineTaskTemplateSpecFluent.ParametersNested<A> editParameter(int index);
    public V1alpha1PipelineTaskTemplateSpecFluent.ParametersNested<A> editFirstParameter();
    public V1alpha1PipelineTaskTemplateSpecFluent.ParametersNested<A> editLastParameter();
    public V1alpha1PipelineTaskTemplateSpecFluent.ParametersNested<A> editMatchingParameter(io.alauda.devops.java.client.fluent.Predicate<V1alpha1PipelineParameterBuilder> predicate);
    
/**
 * This method has been deprecated, please use method buildView instead.
 * @return The buildable object.
 */
@Deprecated public V1alpha1PipelineViewTemplateSpec getView();
    public V1alpha1PipelineViewTemplateSpec buildView();
    public A withView(V1alpha1PipelineViewTemplateSpec view);
    public Boolean hasView();
    public V1alpha1PipelineTaskTemplateSpecFluent.ViewNested<A> withNewView();
    public V1alpha1PipelineTaskTemplateSpecFluent.ViewNested<A> withNewViewLike(V1alpha1PipelineViewTemplateSpec item);
    public V1alpha1PipelineTaskTemplateSpecFluent.ViewNested<A> editView();
    public V1alpha1PipelineTaskTemplateSpecFluent.ViewNested<A> editOrNewView();
    public V1alpha1PipelineTaskTemplateSpecFluent.ViewNested<A> editOrNewViewLike(V1alpha1PipelineViewTemplateSpec item);

    public interface AgentNested<N> extends io.alauda.devops.java.client.fluent.Nested<N>,V1alpha1JenkinsAgentFluent<V1alpha1PipelineTaskTemplateSpecFluent.AgentNested<N>>{

        
    public N and();    public N endAgent();
}
    public interface ArgumentsNested<N> extends io.alauda.devops.java.client.fluent.Nested<N>,V1alpha1PipelineTaskArgumentFluent<V1alpha1PipelineTaskTemplateSpecFluent.ArgumentsNested<N>>{

        
    public N and();    public N endArgument();
}
    public interface DependenciesNested<N> extends io.alauda.devops.java.client.fluent.Nested<N>,V1alpha1PipelineDependencyFluent<V1alpha1PipelineTaskTemplateSpecFluent.DependenciesNested<N>>{

        
    public N and();    public N endDependencies();
}
    public interface ExportsNested<N> extends io.alauda.devops.java.client.fluent.Nested<N>,V1alpha1GlobalParameterFluent<V1alpha1PipelineTaskTemplateSpecFluent.ExportsNested<N>>{

        
    public N and();    public N endExport();
}
    public interface ParametersNested<N> extends io.alauda.devops.java.client.fluent.Nested<N>,V1alpha1PipelineParameterFluent<V1alpha1PipelineTaskTemplateSpecFluent.ParametersNested<N>>{

        
    public N and();    public N endParameter();
}
    public interface ViewNested<N> extends io.alauda.devops.java.client.fluent.Nested<N>,V1alpha1PipelineViewTemplateSpecFluent<V1alpha1PipelineTaskTemplateSpecFluent.ViewNested<N>>{

        
    public N and();    public N endView();
}


}
